@@ -10,7 +10,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import IO, Any, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -68,7 +68,7 @@ FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
         "arrayValue": Dict[str, Any],
-        "blobValue": bytes,
+        "blobValue": Union[bytes, IO[bytes]],
         "booleanValue": bool,
         "doubleValue": float,
         "isNull": bool,
@@ -126,7 +126,7 @@ ValueTypeDef = TypedDict(
         "arrayValues": List[Dict[str, Any]],
         "bigIntValue": int,
         "bitValue": bool,
-        "blobValue": bytes,
+        "blobValue": Union[bytes, IO[bytes]],
         "doubleValue": float,
         "intValue": int,
         "isNull": bool,
